# GrassmannTN
This is a package that aims to simplify the coding involving Grassmann tensor network.
I try to make the coding as convenient as when you use other standard packages like numpy or scipy.
All the sign factors are computed automatically without explicit user inputs.
Visit [the github repository](https://github.com/ayosprakob/grassmanntn) for more info.

## Prerequisites

- [numpy](https://numpy.org/doc/stable/index.html)
- [sparse](https://sparse.pydata.org/en/stable/)
- [opt_einsum](https://optimized-einsum.readthedocs.io/en/stable/)
